prism.cli module — prism documentation

# prism.cli module

Module that contains the command line app.

Why does this file exist, and why not put this in __main__?

> You might be tempted to import things from __main__ later, but that will cause problems: the code will get executed twice:

> - When you run python -mprism python will execute `__main__.py` as a script. That means there won’t be any `prism.__main__` in `sys.modules`.
> - When you import __main__ it will get executed again (as a module) because there’s no `prism.__main__` in `sys.modules`.

> Also see (1) from http://click.pocoo.org/5/setuptools/#setuptools-integration

`prism.cli.` `argument`(*name_or_flags, **kwargs)

`prism.cli.` `argument_bool`(short, long, default=None, required=False, **kwargs)

`prism.cli.` `argument_float`(short, long, default=None, required=False, **kwargs)

`prism.cli.` `argument_int`(short, long, default=None, required=False, **kwargs)

`prism.cli.` `argument_list`(short, long, default=None, required=False, **kwargs)

`prism.cli.` `argument_string`(short, long, default=None, required=False, **kwargs)

`prism.cli.` `main`(args=None)

`prism.cli.` `subcommand`(args=[], parent=_SubParsersAction(option_strings=[], dest='subcommand', nargs='A...', const=None, default=None, type=None, choices={'extract': ArgumentParser(prog='sphinx-build extract', usage=None, description='Run epiloci extraction step of PRISM workflow.\n ', formatter_class=<class 'argparse.HelpFormatter'>, conflict_handler='error', add_help=True), 'preprocess': ArgumentParser(prog='sphinx-build preprocess', usage=None, description='Run preprocessing step of PRISM workflow.\n ', formatter_class=<class 'argparse.HelpFormatter'>, conflict_handler='error', add_help=True), 'deconvolute': ArgumentParser(prog='sphinx-build deconvolute', usage=None, description='Solve beta-binomial mixture of FF to detect subclones.\n ', formatter_class=<class 'argparse.HelpFormatter'>, conflict_handler='error', add_help=True), 'scatter': ArgumentParser(prog='sphinx-build scatter', usage=None, description='Generate scatterplot showing the fractions of fingerprint patterns.\n ', formatter_class=<class 'argparse.HelpFormatter'>, conflict_handler='error', add_help=True), 'annotate': ArgumentParser(prog='sphinx-build annotate', usage=None, description='Annotate epiloci with given annotation bed files.\n Optionally, a scatterplot with annotation marks can be generated.\n ', formatter_class=<class 'argparse.HelpFormatter'>, conflict_handler='error', add_help=True)}, help=None, metavar=None))